==> inline_tooltips-1.2.0%2B1.21.1-fabric-sources.jar: cc/cassian/inline_tooltips/mixin/HideAttributesMixin.java <==
package cc.cassian.inline_tooltips.mixin;

import cc.cassian.inline_tooltips.helpers.ModHelpers;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.apache.commons.lang3.mutable.MutableBoolean;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.function.Consumer;
import net.minecraft.class_1322;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_6880;

import static cc.cassian.inline_tooltips.InlineTooltips.CONFIG;


@Mixin(class_1799.class)
public class HideAttributesMixin {
    //? if fabric {
	@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "method_57370")
	private static boolean init(MutableBoolean instance, Operation<Boolean> original, @Local Consumer<class_2561> consumer, @Local class_1322 attributeModifier) {
        // Disable default tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            return original.call(instance);
        }
        return false;
    }

    //? if >1.21.8 {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/component/ItemAttributeModifiers$Display;apply(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "method_57370")
    private static void init(ItemAttributeModifiers.Display instance, Consumer<Component> consumer, Player player, Holder<Attribute> attributeHolder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, attributeHolder, attributeModifier);
        }
    }
    *///?} else {
    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;addModifierTooltip(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "method_57370")
    private static void removeAttribute(class_1799 instance, Consumer consumer, class_1657 player, class_6880 holder, class_1322 attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, holder, attributeModifier);
        }
    }
    //?}


    //?} else if neoforge && >1.21.8 {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "lambda$addAttributeTooltips$19")
    private static boolean init(MutableBoolean instance, Operation<Boolean> original) {
        // Disable default tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance);
        }
        return false;
    }


    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/component/ItemAttributeModifiers$Display;apply(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "lambda$addAttributeTooltips$19")
    private static void init(ItemAttributeModifiers.Display instance, Consumer<Component> consumer, Player player, Holder<Attribute> attributeHolder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, attributeHolder, attributeModifier);
        }
    }
    *///?} else {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "lambda$addAttributeTooltips$21")
    private static boolean init(MutableBoolean instance, Operation<Boolean> original) {
        // Disable default tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance);
        }
        return false;
    }


    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;addModifierTooltip(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "lambda$addAttributeTooltips$21")
    private static void init(ItemStack instance, Consumer consumer, Player player, Holder holder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (ModHelpers.hasShiftDown() || !CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, holder, attributeModifier);
        }
    }
    *///?}

}

==> inline_tooltips-1.4.0%2B1.21.10-fabric-sources.jar: cc/cassian/inline_tooltips/mixin/HideAttributesMixin.java <==
package cc.cassian.inline_tooltips.mixin;

import cc.cassian.inline_tooltips.helpers.ModHelpers;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.apache.commons.lang3.mutable.MutableBoolean;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.function.Consumer;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_6880;
import net.minecraft.class_9285;

import static cc.cassian.inline_tooltips.InlineTooltips.CONFIG;


@Mixin(class_1799.class)
public class HideAttributesMixin {
    //? if fabric {
	@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "method_57370")
	private static boolean init(MutableBoolean instance, Operation<Boolean> original, @Local Consumer<class_2561> consumer, @Local class_1322 attributeModifier) {
        // Disable default tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            return original.call(instance);
        }
        return false;
    }

    //? if >1.21.8 {
    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/component/ItemAttributeModifiers$Display;apply(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "method_57370")
    private static void init(class_9285.class_11193 instance, Consumer<class_2561> consumer, class_1657 player, class_6880<class_1320> attributeHolder, class_1322 attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, attributeHolder, attributeModifier);
        }
    }
    //?} else {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;addModifierTooltip(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "method_57370")
    private static void removeAttribute(ItemStack instance, Consumer consumer, Player player, Holder holder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, holder, attributeModifier);
        }
    }
    *///?}


    //?} else if neoforge && >1.21.8 {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "lambda$addAttributeTooltips$19")
    private static boolean init(MutableBoolean instance, Operation<Boolean> original) {
        // Disable default tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance);
        }
        return false;
    }


    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/component/ItemAttributeModifiers$Display;apply(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "lambda$addAttributeTooltips$19")
    private static void init(ItemAttributeModifiers.Display instance, Consumer<Component> consumer, Player player, Holder<Attribute> attributeHolder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, attributeHolder, attributeModifier);
        }
    }
    *///?} else {
    /*@WrapOperation(at = @At(value = "INVOKE", target = "Lorg/apache/commons/lang3/mutable/MutableBoolean;isTrue()Z"), method = "lambda$addAttributeTooltips$21")
    private static boolean init(MutableBoolean instance, Operation<Boolean> original) {
        // Disable default tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance);
        }
        return false;
    }


    @WrapOperation(at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;addModifierTooltip(Ljava/util/function/Consumer;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/core/Holder;Lnet/minecraft/world/entity/ai/attributes/AttributeModifier;)V"), method = "lambda$addAttributeTooltips$21")
    private static void init(ItemStack instance, Consumer consumer, Player player, Holder holder, AttributeModifier attributeModifier, Operation<Void> original) {
        // Enable our tooltip
        if (!CONFIG.iconTooltips.attributeTooltips) {
            original.call(instance, consumer, player, holder, attributeModifier);
        }
    }
    *///?}

}
